pub enum Context<'a, I: Interpretation> {
Subject,
Predicate {
subject: ResourceOrIriRef<'a, I>,
},
Object {
subject: ResourceOrIriRef<'a, I>,
predicate: ResourceOrIriRef<'a, I>,
},
}Expand description
Position a value occupies while being visited, used to report errors.
Variants
Subject
The value is a subject.
Predicate
The value is a predicate of the given subject.
Fields

subject: ResourceOrIriRef<'a, I>Subject the predicate belongs to.
Object
The value is an object of the given subject and predicate.
Fields

subject: ResourceOrIriRef<'a, I>Subject the object belongs to.

predicate: ResourceOrIriRef<'a, I>Predicate the object belongs to.
Implementations
Sourceimpl<'a, I: Interpretation> Context<'a, I>
impl<'a, I: Interpretation> Context<'a, I>
Sourcepub fn with_subject(self, subject: &'a I::Resource) -> Self
pub fn with_subject(self, subject: &'a I::Resource) -> Self
Moves this context into the predicate position of subject.
Sourcepub fn with_predicate(self, predicate: &'a I::Resource) -> Self
pub fn with_predicate(self, predicate: &'a I::Resource) -> Self
Moves this context into the object position of predicate.
Sourcepub fn with_predicate_iri(self, predicate: Iri<&'a str>) -> Self
pub fn with_predicate_iri(self, predicate: Iri<&'a str>) -> Self
Moves this context into the object position of the predicate IRI.
Sourcepub fn with_anonymous_predicate(self) -> Self
pub fn with_anonymous_predicate(self) -> Self
Moves this context into the object position of an anonymous predicate.
Sourcepub fn into_iris(self, interpretation: &I) -> ContextIriswhere
I: ReverseInterpretation,
pub fn into_iris(self, interpretation: &I) -> ContextIriswhere
I: ReverseInterpretation,
Resolves the resources of this context into IRIs.