pub enum IntoQuadsError {
Graph,
Subject,
Predicate,
MissingLexicalRepresentation,
}Expand description
Error raised while serializing a value into quads.
Variants
Graph
A resource used as a graph label is neither an IRI nor a blank node.
Subject
A resource used as a subject is neither an IRI nor a blank node.
Predicate
A resource used as a predicate is not an IRI.
MissingLexicalRepresentation
A resource has no lexical representation in the interpretation.