pub enum RdfLiteral {
Any(String, LiteralType),
Xsd(Value),
Json(Value),
}Expand description
Owned RDF literal, kept in its most specific known form.
Variants
Any(String, LiteralType)
Literal held as a lexical value and a datatype.
Xsd(Value)
Literal held as a parsed XSD value.
Json(Value)
Literal held as a parsed rdf:JSON value.
Implementations
Sourceimpl RdfLiteral
impl RdfLiteral
Sourcepub fn into_lexical(self) -> Literal
pub fn into_lexical(self) -> Literal
Converts this literal into its lexical form.
Sourcepub fn as_literal_ref(&self) -> RdfLiteralRef<'_>
pub fn as_literal_ref(&self) -> RdfLiteralRef<'_>
Borrows this literal.
Sourcepub fn embed_into<I: InterpretationMut>(
self,
interpretation: &mut I,
) -> I::Resource
pub fn embed_into<I: InterpretationMut>( self, interpretation: &mut I, ) -> I::Resource
Inserts this literal into interpretation, returning its resource.