RdfLiteralRef

Enum RdfLiteralRef 

pub enum RdfLiteralRef<'a> {
    Any(&'a str, LiteralTypeRef<'a>),
    Xsd(ValueRef<'a>),
    Json(&'a Value),
}
Borrowed RDF literal, kept in its most specific known form.

Variants



Any(&'a str, LiteralTypeRef<'a>)

Literal held as a lexical value and a datatype.



Xsd(ValueRef<'a>)

Literal held as a parsed XSD value.



Json(&'a Value)

Literal held as a parsed rdf:JSON value.

Implementations

Source

impl<'a> RdfLiteralRef<'a>

pub fn into_lexical(self) -> Literal

Converts this literal into its lexical form.

pub fn into_owned(self) -> RdfLiteral

Clones this literal into an owned one.