pub enum ResourceInterpretation<'a, I: Interpretation> {
Interpreted(&'a I::Resource),
Uninterpreted(Option<CowRdfTerm<'a>>),
}Expand description
Resource interpretation.
Variants
Interpreted(&'a I::Resource)
Interpreted resource.
Uninterpreted(Option<CowRdfTerm<'a>>)
Uninterpreted resource with the given optional lexical representation.
It can be used to give an actual interpretation to the resource, bound to its lexical representation.
Implementations
Sourceimpl<'a, I: Interpretation> ResourceInterpretation<'a, I>
impl<'a, I: Interpretation> ResourceInterpretation<'a, I>
Sourcepub fn as_interpreted(&self) -> Option<&'a I::Resource>
pub fn as_interpreted(&self) -> Option<&'a I::Resource>
Returns the interpreted resource, if this interpretation is one.
Sourcepub fn as_uninterpreted(&self) -> Option<&CowRdfTerm<'a>>
pub fn as_uninterpreted(&self) -> Option<&CowRdfTerm<'a>>
Returns the lexical term, if this interpretation is uninterpreted.
Sourcepub fn into_lexical_representation(
self,
interpretation: &'a I,
) -> Option<CowRdfTerm<'a>>where
I: ReverseInterpretation + ReverseLocalInterpretation,
pub fn into_lexical_representation(
self,
interpretation: &'a I,
) -> Option<CowRdfTerm<'a>>where
I: ReverseInterpretation + ReverseLocalInterpretation,
Resolves this interpretation into a lexical term, looking the resource
up in interpretation when necessary.