pub struct AnonymousGraph<T>(pub T);Expand description
Wrapper serializing its value as an anonymous graph.
Tuple Fields
0: TTrait Implementations
Sourceimpl<I: Interpretation, T: LinkedDataGraph<I>> LinkedData<I> for AnonymousGraph<T>
impl<I: Interpretation, T: LinkedDataGraph<I>> LinkedData<I> for AnonymousGraph<T>
Sourceimpl<I: Interpretation, T: LinkedDataGraph<I>> LinkedDataGraph<I> for AnonymousGraph<T>
impl<I: Interpretation, T: LinkedDataGraph<I>> LinkedDataGraph<I> for AnonymousGraph<T>
Sourcefn visit_graph<S>(&self, visitor: S) -> Result<S::Ok, S::Error>where
S: GraphVisitor<I>,
fn visit_graph<S>(&self, visitor: S) -> Result<S::Ok, S::Error>where
S: GraphVisitor<I>,
Visits the subjects of the graph represented by this value.
Sourceimpl<I: Interpretation, T: LinkedDataGraph<I>> LinkedDataPredicateObjects<I> for AnonymousGraph<T>
impl<I: Interpretation, T: LinkedDataGraph<I>> LinkedDataPredicateObjects<I> for AnonymousGraph<T>
Sourcefn visit_objects<S>(&self, visitor: S) -> Result<S::Ok, S::Error>where
S: PredicateObjectsVisitor<I>,
fn visit_objects<S>(&self, visitor: S) -> Result<S::Ok, S::Error>where
S: PredicateObjectsVisitor<I>,
Visits the objects this predicate points at.
Sourceimpl<I: Interpretation, T> LinkedDataResource<I> for AnonymousGraph<T>
impl<I: Interpretation, T> LinkedDataResource<I> for AnonymousGraph<T>
Sourcefn interpretation(
&self,
_interpretation: &mut I,
) -> ResourceInterpretation<'_, I>
fn interpretation( &self, _interpretation: &mut I, ) -> ResourceInterpretation<'_, I>
Returns the interpretation of this resource, inserting it into
interpretation if required.Sourcefn lexical_representation<'a>(
&'a self,
interpretation: &'a mut I,
) -> Option<CowRdfTerm<'a>>where
I: ReverseInterpretation + ReverseLocalInterpretation,
fn lexical_representation<'a>(
&'a self,
interpretation: &'a mut I,
) -> Option<CowRdfTerm<'a>>where
I: ReverseInterpretation + ReverseLocalInterpretation,
Returns the lexical term representing this resource, if any.
Sourcefn reference_interpretation(
&self,
interpretation: &mut I,
) -> ResourceInterpretation<'_, I>
fn reference_interpretation( &self, interpretation: &mut I, ) -> ResourceInterpretation<'_, I>
Returns the interpretation to use when this resource appears as a
reference rather than as a subject with properties.
Sourceimpl<I: Interpretation, T: LinkedDataGraph<I>> LinkedDataSubject<I> for AnonymousGraph<T>
impl<I: Interpretation, T: LinkedDataGraph<I>> LinkedDataSubject<I> for AnonymousGraph<T>
Sourcefn visit_subject<S>(&self, serializer: S) -> Result<S::Ok, S::Error>where
S: SubjectVisitor<I>,
fn visit_subject<S>(&self, serializer: S) -> Result<S::Ok, S::Error>where
S: SubjectVisitor<I>,
Visits the properties of the subject represented by this value.