pub struct Ref<T>(pub T);Expand description
Wrapper serializing its value as a reference: the subject is emitted as an object, without its own properties.
Tuple Fields
0: TTrait Implementations
impl<T: Copy> Copy for Ref<T>
Sourceimpl<'de, T> Deserialize<'de> for Ref<T>where
T: Deserialize<'de>,
impl<'de, T> Deserialize<'de> for Ref<T>where
T: Deserialize<'de>,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl<T: Eq> Eq for Ref<T>
Sourceimpl<I: Interpretation, T: LinkedDataResource<I>> LinkedData<I> for Ref<T>
impl<I: Interpretation, T: LinkedDataResource<I>> LinkedData<I> for Ref<T>
Sourceimpl<I: Interpretation, T: LinkedDataResource<I>> LinkedDataGraph<I> for Ref<T>
impl<I: Interpretation, T: LinkedDataResource<I>> LinkedDataGraph<I> for Ref<T>
Sourcefn visit_graph<S>(&self, visitor: S) -> Result<S::Ok, S::Error>where
S: GraphVisitor<I>,
fn visit_graph<S>(&self, visitor: S) -> Result<S::Ok, S::Error>where
S: GraphVisitor<I>,
Visits the subjects of the graph represented by this value.
Sourceimpl<I: Interpretation, T: LinkedDataResource<I>> LinkedDataPredicateObjects<I> for Ref<T>
impl<I: Interpretation, T: LinkedDataResource<I>> LinkedDataPredicateObjects<I> for Ref<T>
Sourcefn visit_objects<S>(&self, visitor: S) -> Result<S::Ok, S::Error>where
S: PredicateObjectsVisitor<I>,
fn visit_objects<S>(&self, visitor: S) -> Result<S::Ok, S::Error>where
S: PredicateObjectsVisitor<I>,
Visits the objects this predicate points at.
Sourceimpl<I: Interpretation, T: LinkedDataResource<I>> LinkedDataResource<I> for Ref<T>
impl<I: Interpretation, T: LinkedDataResource<I>> LinkedDataResource<I> for Ref<T>
Sourcefn interpretation(
&self,
interpretation: &mut I,
) -> ResourceInterpretation<'_, I>
fn interpretation( &self, interpretation: &mut I, ) -> ResourceInterpretation<'_, I>
Returns the interpretation of this resource, inserting it into
interpretation if required.Sourcefn lexical_representation<'a>(
&'a self,
interpretation: &'a mut I,
) -> Option<CowRdfTerm<'a>>where
I: ReverseInterpretation + ReverseLocalInterpretation,
fn lexical_representation<'a>(
&'a self,
interpretation: &'a mut I,
) -> Option<CowRdfTerm<'a>>where
I: ReverseInterpretation + ReverseLocalInterpretation,
Returns the lexical term representing this resource, if any.
Sourcefn reference_interpretation(
&self,
interpretation: &mut I,
) -> ResourceInterpretation<'_, I>
fn reference_interpretation( &self, interpretation: &mut I, ) -> ResourceInterpretation<'_, I>
Returns the interpretation to use when this resource appears as a
reference rather than as a subject with properties.
Sourceimpl<I: Interpretation, T> LinkedDataSubject<I> for Ref<T>
impl<I: Interpretation, T> LinkedDataSubject<I> for Ref<T>
Sourcefn visit_subject<S>(&self, serializer: S) -> Result<S::Ok, S::Error>where
S: SubjectVisitor<I>,
fn visit_subject<S>(&self, serializer: S) -> Result<S::Ok, S::Error>where
S: SubjectVisitor<I>,
Visits the properties of the subject represented by this value.
Sourceimpl<T: Ord> Ord for Ref<T>
impl<T: Ord> Ord for Ref<T>
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<T: PartialOrd> PartialOrd for Ref<T>
impl<T: PartialOrd> PartialOrd for Ref<T>
impl<T: PartialEq> StructuralPartialEq for Ref<T>