LinkedDataDeserializePredicateObjects

Trait LinkedDataDeserializePredicateObjects 

pub trait LinkedDataDeserializePredicateObjects<I: Interpretation>: Sized
where I::Resource: Resource,
{ // Required method fn deserialize_objects_in<'a, D>( interpretation: &I, dataset: &D, graph: Option<&I::Resource>, objects: impl IntoIterator<Item = &'a I::Resource>, context: Context<'_, I>, ) -> Result<Self, FromLinkedDataError> where I::Resource: 'a, D: PatternMatchingDataset<Subject = I::Resource>; // Provided method fn deserialize_objects<'a, D>( interpretation: &I, dataset: &D, graph: Option<&I::Resource>, objects: impl IntoIterator<Item = &'a I::Resource>, ) -> Result<Self, FromLinkedDataError> where I::Resource: 'a, D: PatternMatchingDataset<Subject = I::Resource> { ... } }
Type that can be deserialized from the objects of a predicate.

Required Methods

fn deserialize_objects_in<'a, D>( interpretation: &I, dataset: &D, graph: Option<&I::Resource>, objects: impl IntoIterator<Item = &'a I::Resource>, context: Context<'_, I>, ) -> Result<Self, FromLinkedDataError>
where I::Resource: 'a, D: PatternMatchingDataset<Subject = I::Resource>,

Deserializes a value from objects, reporting errors against context.

Provided Methods

fn deserialize_objects<'a, D>( interpretation: &I, dataset: &D, graph: Option<&I::Resource>, objects: impl IntoIterator<Item = &'a I::Resource>, ) -> Result<Self, FromLinkedDataError>
where I::Resource: 'a, D: PatternMatchingDataset<Subject = I::Resource>,

Deserializes a value from objects.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<I, T: LinkedDataDeserializeSubject<I>> LinkedDataDeserializePredicateObjects<I> for Option<T>

Source

fn deserialize_objects_in<'a, D>( interpretation: &I, dataset: &D, graph: Option<&I::Resource>, objects: impl IntoIterator<Item = &'a I::Resource>, context: Context<'_, I>, ) -> Result<Self, FromLinkedDataError>
where I::Resource: 'a, D: PatternMatchingDataset<Subject = I::Resource>,

Source

impl<I: Interpretation, T: LinkedDataDeserializePredicateObjects<I>> LinkedDataDeserializePredicateObjects<I> for Box<T>
where I::Resource: Resource,

Source

fn deserialize_objects_in<'a, D>( interpretation: &I, dataset: &D, graph: Option<&I::Resource>, objects: impl IntoIterator<Item = &'a I::Resource>, context: Context<'_, I>, ) -> Result<Self, FromLinkedDataError>
where I::Resource: 'a, D: PatternMatchingDataset<Subject = I::Resource>,

Source

impl<I> LinkedDataDeserializePredicateObjects<I> for BlankIdBuf

Source

fn deserialize_objects_in<'a, D>( interpretation: &I, dataset: &D, graph: Option<&I::Resource>, objects: impl IntoIterator<Item = &'a I::Resource>, context: Context<'_, I>, ) -> Result<Self, FromLinkedDataError>
where I::Resource: 'a, D: PatternMatchingDataset<Subject = I::Resource>,

Source

impl<I> LinkedDataDeserializePredicateObjects<I> for DateTime

Source

fn deserialize_objects_in<'a, D>( interpretation: &I, dataset: &D, graph: Option<&I::Resource>, objects: impl IntoIterator<Item = &'a <I as Interpretation>::Resource>, context: Context<'_, I>, ) -> Result<Self, FromLinkedDataError>
where <I as Interpretation>::Resource: 'a, D: PatternMatchingDataset<Subject = I::Resource>,

Source

impl<I> LinkedDataDeserializePredicateObjects<I> for Id

Source

fn deserialize_objects_in<'a, D>( interpretation: &I, dataset: &D, graph: Option<&I::Resource>, objects: impl IntoIterator<Item = &'a I::Resource>, context: Context<'_, I>, ) -> Result<Self, FromLinkedDataError>
where I::Resource: 'a, D: PatternMatchingDataset<Subject = I::Resource>,

Source

impl<I> LinkedDataDeserializePredicateObjects<I> for IriBuf

Source

fn deserialize_objects_in<'a, D>( interpretation: &I, dataset: &D, graph: Option<&I::Resource>, objects: impl IntoIterator<Item = &'a I::Resource>, context: Context<'_, I>, ) -> Result<Self, FromLinkedDataError>
where I::Resource: 'a, D: PatternMatchingDataset<Subject = I::Resource>,

Source

impl<I> LinkedDataDeserializePredicateObjects<I> for String

Source

fn deserialize_objects_in<'a, D>( interpretation: &I, dataset: &D, graph: Option<&I::Resource>, objects: impl IntoIterator<Item = &'a <I as Interpretation>::Resource>, context: Context<'_, I>, ) -> Result<Self, FromLinkedDataError>
where <I as Interpretation>::Resource: 'a, D: PatternMatchingDataset<Subject = I::Resource>,

Source

impl<I> LinkedDataDeserializePredicateObjects<I> for i8

Source

fn deserialize_objects_in<'a, D>( interpretation: &I, dataset: &D, graph: Option<&I::Resource>, objects: impl IntoIterator<Item = &'a <I as Interpretation>::Resource>, context: Context<'_, I>, ) -> Result<Self, FromLinkedDataError>
where <I as Interpretation>::Resource: 'a, D: PatternMatchingDataset<Subject = I::Resource>,

Source

impl<I> LinkedDataDeserializePredicateObjects<I> for i16

Source

fn deserialize_objects_in<'a, D>( interpretation: &I, dataset: &D, graph: Option<&I::Resource>, objects: impl IntoIterator<Item = &'a <I as Interpretation>::Resource>, context: Context<'_, I>, ) -> Result<Self, FromLinkedDataError>
where <I as Interpretation>::Resource: 'a, D: PatternMatchingDataset<Subject = I::Resource>,

Source

impl<I> LinkedDataDeserializePredicateObjects<I> for i32

Source

fn deserialize_objects_in<'a, D>( interpretation: &I, dataset: &D, graph: Option<&I::Resource>, objects: impl IntoIterator<Item = &'a <I as Interpretation>::Resource>, context: Context<'_, I>, ) -> Result<Self, FromLinkedDataError>
where <I as Interpretation>::Resource: 'a, D: PatternMatchingDataset<Subject = I::Resource>,

Source

impl<I> LinkedDataDeserializePredicateObjects<I> for i64

Source

fn deserialize_objects_in<'a, D>( interpretation: &I, dataset: &D, graph: Option<&I::Resource>, objects: impl IntoIterator<Item = &'a <I as Interpretation>::Resource>, context: Context<'_, I>, ) -> Result<Self, FromLinkedDataError>
where <I as Interpretation>::Resource: 'a, D: PatternMatchingDataset<Subject = I::Resource>,

Source

impl<I> LinkedDataDeserializePredicateObjects<I> for u8

Source

fn deserialize_objects_in<'a, D>( interpretation: &I, dataset: &D, graph: Option<&I::Resource>, objects: impl IntoIterator<Item = &'a <I as Interpretation>::Resource>, context: Context<'_, I>, ) -> Result<Self, FromLinkedDataError>
where <I as Interpretation>::Resource: 'a, D: PatternMatchingDataset<Subject = I::Resource>,

Source

impl<I> LinkedDataDeserializePredicateObjects<I> for u16

Source

fn deserialize_objects_in<'a, D>( interpretation: &I, dataset: &D, graph: Option<&I::Resource>, objects: impl IntoIterator<Item = &'a <I as Interpretation>::Resource>, context: Context<'_, I>, ) -> Result<Self, FromLinkedDataError>
where <I as Interpretation>::Resource: 'a, D: PatternMatchingDataset<Subject = I::Resource>,

Source

impl<I> LinkedDataDeserializePredicateObjects<I> for u32

Source

fn deserialize_objects_in<'a, D>( interpretation: &I, dataset: &D, graph: Option<&I::Resource>, objects: impl IntoIterator<Item = &'a <I as Interpretation>::Resource>, context: Context<'_, I>, ) -> Result<Self, FromLinkedDataError>
where <I as Interpretation>::Resource: 'a, D: PatternMatchingDataset<Subject = I::Resource>,

Source

impl<I> LinkedDataDeserializePredicateObjects<I> for u64

Source

fn deserialize_objects_in<'a, D>( interpretation: &I, dataset: &D, graph: Option<&I::Resource>, objects: impl IntoIterator<Item = &'a <I as Interpretation>::Resource>, context: Context<'_, I>, ) -> Result<Self, FromLinkedDataError>
where <I as Interpretation>::Resource: 'a, D: PatternMatchingDataset<Subject = I::Resource>,

Implementors