LinkedDataResource

Trait LinkedDataResource 

pub trait LinkedDataResource<I: Interpretation = ()> {
    // Required method
    fn interpretation(
        &self,
        interpretation: &mut I,
    ) -> ResourceInterpretation<'_, I>;

    // Provided methods
    fn lexical_representation<'a>(
        &'a self,
        interpretation: &'a mut I,
    ) -> Option<CowRdfTerm<'a>>
       where I: ReverseInterpretation + ReverseLocalInterpretation { ... }
    fn reference_interpretation(
        &self,
        interpretation: &mut I,
    ) -> ResourceInterpretation<'_, I> { ... }
}
Type that can have an interpretation.

Required Methods

fn interpretation( &self, interpretation: &mut I, ) -> ResourceInterpretation<'_, I>

Returns the interpretation of this resource, inserting it into interpretation if required.

Provided Methods

fn lexical_representation<'a>( &'a self, interpretation: &'a mut I, ) -> Option<CowRdfTerm<'a>>

Returns the lexical term representing this resource, if any.

fn reference_interpretation( &self, interpretation: &mut I, ) -> ResourceInterpretation<'_, I>

Returns the interpretation to use when this resource appears as a reference rather than as a subject with properties.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<I: Interpretation, T: ?Sized + LinkedDataResource<I>> LinkedDataResource<I> for &T

Source

fn interpretation( &self, interpretation: &mut I, ) -> ResourceInterpretation<'_, I>

Source

impl<I: Interpretation, T: ?Sized + LinkedDataResource<I>> LinkedDataResource<I> for Box<T>

Source

fn interpretation( &self, interpretation: &mut I, ) -> ResourceInterpretation<'_, I>

Source

impl<I: Interpretation, T: LinkedDataResource<I>> LinkedDataResource<I> for Option<T>

Source

fn interpretation( &self, interpretation: &mut I, ) -> ResourceInterpretation<'_, I>

Source

impl<I: Interpretation> LinkedDataResource<I> for ()

Source

fn interpretation( &self, _interpretation: &mut I, ) -> ResourceInterpretation<'_, I>

Source

impl<I: Interpretation> LinkedDataResource<I> for BlankId

Source

fn interpretation( &self, _interpretation: &mut I, ) -> ResourceInterpretation<'_, I>

Source

impl<I: Interpretation> LinkedDataResource<I> for BlankIdBuf

Source

fn interpretation( &self, _interpretation: &mut I, ) -> ResourceInterpretation<'_, I>

Source

impl<I: Interpretation> LinkedDataResource<I> for DateTime

Source

fn interpretation( &self, _interpretation: &mut I, ) -> ResourceInterpretation<'_, I>

Source

impl<I: Interpretation> LinkedDataResource<I> for Id

Source

fn interpretation( &self, _interpretation: &mut I, ) -> ResourceInterpretation<'_, I>

Source

impl<I: Interpretation> LinkedDataResource<I> for Iri<&str>

Source

fn interpretation( &self, _interpretation: &mut I, ) -> ResourceInterpretation<'_, I>

Source

impl<I: Interpretation> LinkedDataResource<I> for IriBuf

Source

fn interpretation( &self, _interpretation: &mut I, ) -> ResourceInterpretation<'_, I>

Source

impl<I: Interpretation> LinkedDataResource<I> for Literal

Source

fn interpretation( &self, _interpretation: &mut I, ) -> ResourceInterpretation<'_, I>

Source

impl<I: Interpretation> LinkedDataResource<I> for LocalTerm

Source

fn interpretation( &self, _interpretation: &mut I, ) -> ResourceInterpretation<'_, I>

Source

impl<I: Interpretation> LinkedDataResource<I> for String

Source

fn interpretation( &self, _interpretation: &mut I, ) -> ResourceInterpretation<'_, I>

Source

impl<I: Interpretation> LinkedDataResource<I> for Term

Source

fn interpretation( &self, _interpretation: &mut I, ) -> ResourceInterpretation<'_, I>

Source

impl<I: Interpretation> LinkedDataResource<I> for i8

Source

fn interpretation( &self, _interpretation: &mut I, ) -> ResourceInterpretation<'_, I>

Source

impl<I: Interpretation> LinkedDataResource<I> for i16

Source

fn interpretation( &self, _interpretation: &mut I, ) -> ResourceInterpretation<'_, I>

Source

impl<I: Interpretation> LinkedDataResource<I> for i32

Source

fn interpretation( &self, _interpretation: &mut I, ) -> ResourceInterpretation<'_, I>

Source

impl<I: Interpretation> LinkedDataResource<I> for i64

Source

fn interpretation( &self, _interpretation: &mut I, ) -> ResourceInterpretation<'_, I>

Source

impl<I: Interpretation> LinkedDataResource<I> for str

Source

fn interpretation( &self, _interpretation: &mut I, ) -> ResourceInterpretation<'_, I>

Source

impl<I: Interpretation> LinkedDataResource<I> for u8

Source

fn interpretation( &self, _interpretation: &mut I, ) -> ResourceInterpretation<'_, I>

Source

impl<I: Interpretation> LinkedDataResource<I> for u16

Source

fn interpretation( &self, _interpretation: &mut I, ) -> ResourceInterpretation<'_, I>

Source

impl<I: Interpretation> LinkedDataResource<I> for u32

Source

fn interpretation( &self, _interpretation: &mut I, ) -> ResourceInterpretation<'_, I>

Source

impl<I: Interpretation> LinkedDataResource<I> for u64

Source

fn interpretation( &self, _interpretation: &mut I, ) -> ResourceInterpretation<'_, I>

Implementors