pub trait LinkedDataResourceRef<'a, I: Interpretation = ()> {
// Required method
fn interpretation_ref(
&self,
interpretation: &mut I,
) -> ResourceInterpretation<'a, I>;
}Expand description
Type that can have an interpretation bound to the given lifetime.
Required Methods
Sourcefn interpretation_ref(
&self,
interpretation: &mut I,
) -> ResourceInterpretation<'a, I>
fn interpretation_ref( &self, interpretation: &mut I, ) -> ResourceInterpretation<'a, I>
Returns the interpretation of this resource, bound to 'a.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".