pub enum ContextIris {
Subject,
Predicate {
subject: Option<IriBuf>,
},
Object {
subject: Option<IriBuf>,
predicate: Option<IriBuf>,
},
}Expand description
Error context with its resources resolved into IRIs.
Variants
Subject
The value is a subject.
Predicate
The value is a predicate of the given subject.
Object
The value is an object of the given subject and predicate.