pub trait LinkedDataResource<I: Interpretation = ()> {
// Required method
fn interpretation(
&self,
interpretation: &mut I,
) -> ResourceInterpretation<'_, I>;
// Provided methods
fn lexical_representation<'a>(
&'a self,
interpretation: &'a mut I,
) -> Option<CowRdfTerm<'a>>
where I: ReverseInterpretation + ReverseLocalInterpretation { ... }
fn reference_interpretation(
&self,
interpretation: &mut I,
) -> ResourceInterpretation<'_, I> { ... }
}Expand description
Type that can have an interpretation.
Required Methods
Sourcefn interpretation(
&self,
interpretation: &mut I,
) -> ResourceInterpretation<'_, I>
fn interpretation( &self, interpretation: &mut I, ) -> ResourceInterpretation<'_, I>
Returns the interpretation of this resource, inserting it into
interpretation if required.
Provided Methods
Sourcefn lexical_representation<'a>(
&'a self,
interpretation: &'a mut I,
) -> Option<CowRdfTerm<'a>>where
I: ReverseInterpretation + ReverseLocalInterpretation,
fn lexical_representation<'a>(
&'a self,
interpretation: &'a mut I,
) -> Option<CowRdfTerm<'a>>where
I: ReverseInterpretation + ReverseLocalInterpretation,
Returns the lexical term representing this resource, if any.
Sourcefn reference_interpretation(
&self,
interpretation: &mut I,
) -> ResourceInterpretation<'_, I>
fn reference_interpretation( &self, interpretation: &mut I, ) -> ResourceInterpretation<'_, I>
Returns the interpretation to use when this resource appears as a reference rather than as a subject with properties.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".